<?php

/**
 * Load the theme options page if in admin mode
 */

if ( ! function_exists( 'the3D_theme_setup' ) ) :
/*
 * Set up theme specific settings
 *
 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_editor_style() To style the visual editor.
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_image_size() To set custom image sizes.
 *
 * @since the3D 1.0
 */
function the3D_theme_setup() {

	// Set default content width based on the theme's layout. This affects the width of post images and embedded media.
	global $content_width;
	if( ! isset( $content_width ) ) $content_width = 695;
	
		// Automatically add feed links to document head
	add_theme_support( 'automatic-feed-links' );
	
	// Allows users to set a custom header image
	add_theme_support( 'custom-header', array(
		'width' => ( the3D_get_option( 'retina_header' ) ? 392 : 196 ),
		'height' => ( the3D_get_option( 'retina_header' ) ? 96 : 48 ),
		'default-text-color' => '333',
		'flex-width' => true,
		'wp-head-callback' => 'the3D_header_style',
		'admin-head-callback' => 'the3D_admin_header_style',
		'admin-preview-callback' => 'the3D_admin_header_image'
	) );
	
	// Allows users to set a custom background
	add_theme_support( 'custom-background', array(
		'default-image' => get_template_directory_uri() . '/images/bg.jpg',
	) );
	
	// Styles the post editor
	add_editor_style();
	
}
$args = array(
	'before'           => '<p>' . 'Pages:',
	'after'            => '</p>',
	'link_before'      => '',
	'link_after'       => '',
	'next_or_number'   => 'number',
	'nextpagelink'     => 'Next page',
	'previouspagelink' => 'Previous page',
	'pagelink'         => '%',
	'echo'             => 1
);
endif;
if ( ! function_exists( 'the3D_enqueue_scripts' ) ) :
/**
 * Enqueue theme scripts
 *
 * @uses wp_enqueue_scripts() To enqueue scripts
 *
 * @since The3D 1.0
 */
function the3D_enqueue_scripts() {
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
}
endif;

if ( ! function_exists( 'the3D_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @since the3D 1.0
 */
function the3D_header_style() { ?>
<style type="text/css">
<?php if ( 'blank' == get_header_textcolor() ) : ?>
	#site-title .home,
	#site-description {
		position:absolute !important;
		clip:rect(1px, 1px, 1px, 1px);
	}
<?php else : ?>
	#site-title a,
	#site-description {
		color:#<?php header_textcolor(); ?>;
	}
<?php endif; ?>
</style>
<?php
}
endif;

if ( ! function_exists( 'the3D_admin_header_style' ) ) :
/**
 * Shows the header image preview in the admin panel.
 *
 * @since the3D 1.0
 */
function the3D_admin_header_style() {
	$header_image = get_header_image(); ?>
<style type="text/css">
	@import url("<?php echo ( is_ssl() ? 'https' : 'http' ); ?>://fonts.googleapis.com/css?family=Oswald:300|Open+Sans:normal&subset=latin");
	.appearance_page_custom-header #headimg {
		max-width:1132px;
		width:100%;
		border:none;
	}
	#headimg {
		padding:0 20px;
		background:#F8F8F8;
	}
	#headimg h1 {
		float:left;
		margin:0;
		font-family:"Oswald", sans-serif;
		font-size:32px;
		font-weight:bold;
		line-height:120px;
	}
	#headimg h1 a {
		text-decoration:none;
	}
	#desc {
		float:left;
		margin-left:20px;
		font-family:"Open Sans", sans-serif;
		font-size:12px;
		font-weight:normal;
		line-height:120px;
	}
	#headimg img {
		max-width: 100%;
		vertical-align:middle;
	}
	#headimg h1 a,
	#desc {
		color:#<?php header_textcolor() ?>;
	}
</style>
<?php
}
endif;

if ( ! function_exists( 'the3D_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @since the3D 1.0
 */
function the3D_admin_header_image() {
	if ( 'blank' == get_header_textcolor() || '' == get_header_textcolor() )
		$style = ' style="display:none;"';
	else
		$style = ' style="color:#' . get_header_textcolor() . ';"';
		$header_image = get_header_image(); ?>
<div id="headimg">
	<h1>
		<?php if ( ! empty( $header_image ) ) : ?>
			<a id="name" onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<img src="<?php header_image(); ?>" alt="<?php bloginfo( 'name' ); ?>" width="<?php echo ( the3D_get_option( 'retina_header' ) ? absint( get_custom_header()->width / 2 ) : get_custom_header()->width ); ?>" height="<?php echo ( the3D_get_option( 'retina_header' ) ? absint( get_custom_header()->height / 2 ) : get_custom_header()->height ); ?>" />
			</a>
		<?php endif; ?>
		<a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
	</h1>
	<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
	<div class="clear"></div>
</div>
<?php
}
endif;



/*******************************
 INCLUDES
********************************/
include 'includes/functions/portfolio.php';


  
add_filter( 'wp_get_attachment_link', 'sant_prettyadd');
 
function sant_prettyadd ($content) {
	$content = preg_replace ("/<a/","<a rel=\"prettyPhoto[slides]\"",$content,1);
	return $content;
}





/*******************************
 MENUS SUPPORT
********************************/
add_filter( 'wp_nav_menu_items', 'add_home_link', 10, 2 );
function add_home_link($items, $args) {
  
        if (is_front_page())
            $class = 'class="current_page_item"';
        else
            $class = '';
  
        $homeMenuItem =
                '<li ' . $class . '>' .
                $args->before .
                '<a href="' . home_url( '/' ) . '" title="Home">' .
                $args->link_before . 'Home' . $args->link_after .
                '</a>' .
                $args->after .
                '</li>';
  
        $items = $homeMenuItem . $items;
  
    return $items;
}

if ( function_exists( 'wp_nav_menu' ) ){
	if (function_exists('add_theme_support')) {
		add_theme_support('nav-menus');
		add_action( 'init', 'register_my_menus' );
		function register_my_menus() {
			register_nav_menus(
				array(
					'main-menu' => 'Main Menu'
				)
			);
		}
	}
}

function primarymenu(){ ?>
			<div id="menu" class="lazymenu">
				<ul>
					<?php wp_list_pages('title_li='); ?>
					<?php wp_list_categories('hide_empty=1&exclude=1&title_li='); ?>
				</ul>
			</div>
<?php }




/*******************************
 THUMBNAIL SUPPORT
********************************/

if ( function_exists( 'add_theme_support' ) ) { 
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 150, 150, true ); // default Post Thumbnail dimensions (cropped)
add_image_size( 'post-thumb', 673, 9999 ); //673 pixels wide (and unlimited height)
add_image_size( 'post-thumb-fullwidth', 928, 9999 ); //928 pixels wide (and unlimited height)
add_image_size( 'portfolio2c-thumb', 455, 9999 ); //455 pixels wide (and unlimited height)
add_image_size( 'portfolio3c-thumb', 297, 9999 ); //297 pixels wide (and unlimited height)
add_image_size( 'portfolio4c-thumb', 300, 9999 ); //300 pixels wide (and unlimited height)
}




/*******************************
 WIDGETS OPTIONS
********************************/
if ( function_exists('register_sidebar') )
register_sidebar(array(
	'name' => 'Sidebar Widgets',
	'before_widget' => '<div class="sidebarcontent">',
	'after_widget' => '</div>',
	'before_title' => '<h2>',
	'after_title' => '</h2>',
));





/*******************************
 COMMENTS OPTIONS
********************************/

function mytheme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class('clearfix'); ?> id="li-comment-<?php comment_ID() ?>">
   	<div class="gravatar">
	 <?php echo get_avatar($comment,$size='50' ); ?>
	 <div class="gravatar_mask"></div>
	</div>
     <div id="comment-<?php comment_ID(); ?>">
	  <div class="comment-meta commentmetadata clearfix">
	    <?php printf('<strong>%s</strong>', get_comment_author_link()) ?><?php edit_comment_link('(edit)','  ','') ?> <br><span><?php printf('on %1$s at %2$s', get_comment_date(),  get_comment_time()) ?>
	  </span>
	  </div>
	  
      <div class="text">
		  <?php comment_text() ?>
	  </div>
	  
	  <?php if ($comment->comment_approved == '0') : ?>
         <em><?php 'Your comment is awaiting moderation.' ?></em>
         <br />
      <?php endif; ?>

      <div class="reply">
         <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
     </div>
<?php }




/*******************************
 THEME PANEL OPTIONS
********************************/
require_once(TEMPLATEPATH . '/includes/panel/admin-functions.php');
require_once(TEMPLATEPATH . '/includes/panel/admin-interface.php');
require_once(TEMPLATEPATH . '/includes/panel/theme-settings.php');

?>